<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2023 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @subpackage Test
 * @author     Tim College <tcollege@interworx.com>
 * @date       Nov 29, 2023
 */

class ApiKeyTest extends IWorx_Framework_TestCase
{
    /**
     * Test v1 db format version detection.
     */
    public function testV1DbFormatVersionDetection()
    {
        $key = $this->_getV1InternalKey();

        $this->assertEquals(API_Key::VERSION_1, API_Key::getDbKeyVersion($key));
    }

    /**
     * Test v1 pretty format version detection.
     *
     * @return void
     */
    public function testV1PrettyFormatVersionDetection()
    {
        $key = $this->_getV1PrettyKey();

        $this->assertEquals(API_Key::VERSION_1, API_Key::getPrettyKeyVersion($key));
    }

    /**
     * Test converting v1 pretty to db format.
     */
    public function testV1Pretty2Db()
    {
        $v1_pretty = $this->_getV1PrettyKey();
        $expected  = $this->_getV1InternalKey();

        $actual = API_Key::pretty2db($v1_pretty)[1];

        $this->assertEquals($expected, $actual, 'v1 pretty key did not decode as expected');
    }

    /**
     * Test converting v1 db to pretty format.
     */
    public function testV1Db2Pretty()
    {
        $v1_internal = $this->_getV1InternalKey();
        $expected    = $this->_getV1PrettyKey();

        $actual = API_Key::db2pretty(1, $v1_internal);

        $this->assertEquals($expected, $actual, 'v1 internal key did not encode as expected');
    }

    /**
     * Test converting from pretty to db back to pretty.
     */
    public function testV1Pretty2Db2Pretty()
    {
        $pretty = $this->_getV1PrettyKey();

        $actual = API_Key::db2pretty(1, API_Key::pretty2db($pretty)[1]);

        $this->assertEquals($pretty, $actual);
    }

    /**
     * Test v2 db format version detection.
     */
    public function testV2DbFormatVersionDetection()
    {
        $key = $this->_getV2InternalKey();

        $this->assertEquals(API_Key::VERSION_2, API_Key::getDbKeyVersion($key));
    }

    /**
     * Test v2 pretty format version detection.
     *
     * @return void
     */
    public function testV2PrettyFormatVersionDetection()
    {
        $key = $this->_getV2PrettyKey();

        $this->assertEquals(API_Key::VERSION_2, API_Key::getPrettyKeyVersion($key));
    }

    /**
     * Test converting v2 pretty to db format.
     */
    public function testV2Pretty2Db()
    {
        $v2_pretty = $this->_getV2PrettyKey();
        $expected  = $this->_getV2InternalKey();

        $actual = API_Key::pretty2db($v2_pretty)[1];

        $this->assertEquals($expected, $actual, 'v2 pretty key did not decode as expected');
    }

    /**
     * Test converting v2 db to pretty format.
     */
    public function testV2Db2Pretty()
    {
        $v2_internal = $this->_getV2InternalKey();
        $expected    = $this->_getV2PrettyKey();

        $actual = API_Key::db2pretty(1, $v2_internal);

        $this->assertEquals($expected, $actual, 'v2 internal key did not encode as expected');
    }

    /**
     * Test converting from pretty to db back to pretty.
     */
    public function testV2Pretty2Db2Pretty()
    {
        $pretty = $this->_getV2PrettyKey();

        $actual = API_Key::db2pretty(1, API_Key::pretty2db($pretty)[1]);

        $this->assertEquals($pretty, $actual);
    }

    /**
     * Get the pretty version of a v1 API key.
     *
     * @return string
     */
    private function _getV1PrettyKey() : string
    {
        return trim(file_get_contents('/home/interworx/TESTS/_resources/apikeys/v1-api-key-pretty-format'));
    }

    /**
     * Get the internal version of a v1 API key.
     *
     * @return string
     */
    private function _getV1InternalKey() : string
    {
        return trim(file_get_contents('/home/interworx/TESTS/_resources/apikeys/v1-api-key-internal-format'));
    }

    /**
     * Get the pretty version of a v2 API key.
     *
     * @return string
     */
    private function _getV2PrettyKey() : string
    {
        return trim(file_get_contents('/home/interworx/TESTS/_resources/apikeys/v2-api-key-pretty-format'));
    }

    /**
     * Get the internal version of a v2 API key.
     *
     * @return string
     */
    private function _getV2InternalKey() : string
    {
        return trim(file_get_contents('/home/interworx/TESTS/_resources/apikeys/v2-api-key-internal-format'));
    }
}
